Skip to contents

Evaluate the analytical value of \(\eta\) for bivariate Gaussian, logistic, asymmetric logistic, and inverted logistic copulas

Usage

eta_analytical(theta, dep = NULL)

Arguments

theta

Strength of dependence, between (0,1)

dep

Copula; g for Gaussian, l for logistic, il for inverted logistic, al for asymmetric logistic

Value

scalar value of \(\eta\)