bezier_intersection.Rd
Find the intersection of a 2D Bezier curve B(t) and a line passing through the origin with slope m
bezier_intersection(p0, p1, p2, m)
Start control point
Intermediate control point
End control point
Slope of straight line passing through the origin
Value of t where the line intersects the curve B(t)
bezier_intersection(p0 = c(0.4,0.1),p1 = c(0.9,0.9),p2 = c(0.1,0.4),m = 1) #> [1] 0.5