Truncated Gamma calculations
Arguments
- x
bivariate data with exponential margins, in a matrix with 2 colums
- tau
quantile level for marginal threshold
Value
r_0_marg truncation point for truncated Gamma distribution
above_thresh_marg TRUE/FALSE vector of whether points are above the marginal threshold